# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.edgeorder import EdgeOrderManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestEdgeOrderManagement(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(EdgeOrderManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_operations(self, resource_group):
        response = self.client.list_operations(
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_addresses_at_subscription_level(self, resource_group):
        response = self.client.list_addresses_at_subscription_level(
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_product_families(self, resource_group):
        response = self.client.list_product_families(
            product_families_request={
                "filterableProperties": {"str": [{"supportedValues": ["str"], "type": "str"}]},
                "customerSubscriptionDetails": {
                    "quotaId": "str",
                    "locationPlacementId": "str",
                    "registeredFeatures": [{"name": "str", "state": "str"}],
                },
            },
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_configurations(self, resource_group):
        response = self.client.list_configurations(
            configurations_request={
                "configurationFilters": [
                    {
                        "hierarchyInformation": {
                            "configurationName": "str",
                            "productFamilyName": "str",
                            "productLineName": "str",
                            "productName": "str",
                        },
                        "filterableProperty": [{"supportedValues": ["str"], "type": "str"}],
                    }
                ],
                "customerSubscriptionDetails": {
                    "quotaId": "str",
                    "locationPlacementId": "str",
                    "registeredFeatures": [{"name": "str", "state": "str"}],
                },
            },
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_product_families_metadata(self, resource_group):
        response = self.client.list_product_families_metadata(
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_order_at_subscription_level(self, resource_group):
        response = self.client.list_order_at_subscription_level(
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_order_items_at_subscription_level(self, resource_group):
        response = self.client.list_order_items_at_subscription_level(
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_addresses_at_resource_group_level(self, resource_group):
        response = self.client.list_addresses_at_resource_group_level(
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_address_by_name(self, resource_group):
        response = self.client.get_address_by_name(
            address_name="str",
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_address(self, resource_group):
        response = self.client.begin_create_address(
            address_name="str",
            resource_group_name=resource_group.name,
            address_resource={
                "contactDetails": {
                    "contactName": "str",
                    "emailList": ["str"],
                    "phone": "str",
                    "mobile": "str",
                    "phoneExtension": "str",
                },
                "location": "str",
                "addressValidationStatus": "str",
                "id": "str",
                "name": "str",
                "shippingAddress": {
                    "country": "str",
                    "streetAddress1": "str",
                    "addressType": "str",
                    "city": "str",
                    "companyName": "str",
                    "postalCode": "str",
                    "stateOrProvince": "str",
                    "streetAddress2": "str",
                    "streetAddress3": "str",
                    "zipExtendedCode": "str",
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_delete_address_by_name(self, resource_group):
        response = self.client.begin_delete_address_by_name(
            address_name="str",
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_update_address(self, resource_group):
        response = self.client.begin_update_address(
            address_name="str",
            resource_group_name=resource_group.name,
            address_update_parameter={
                "contactDetails": {
                    "contactName": "str",
                    "emailList": ["str"],
                    "phone": "str",
                    "mobile": "str",
                    "phoneExtension": "str",
                },
                "shippingAddress": {
                    "country": "str",
                    "streetAddress1": "str",
                    "addressType": "str",
                    "city": "str",
                    "companyName": "str",
                    "postalCode": "str",
                    "stateOrProvince": "str",
                    "streetAddress2": "str",
                    "streetAddress3": "str",
                    "zipExtendedCode": "str",
                },
                "tags": {"str": "str"},
            },
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_order_at_resource_group_level(self, resource_group):
        response = self.client.list_order_at_resource_group_level(
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_order_by_name(self, resource_group):
        response = self.client.get_order_by_name(
            order_name="str",
            resource_group_name=resource_group.name,
            location="str",
            api_version="2021-12-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_list_order_items_at_resource_group_level(self, resource_group):
        response = self.client.list_order_items_at_resource_group_level(
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_get_order_item_by_name(self, resource_group):
        response = self.client.get_order_item_by_name(
            order_item_name="str",
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_create_order_item(self, resource_group):
        response = self.client.begin_create_order_item(
            order_item_name="str",
            resource_group_name=resource_group.name,
            order_item_resource={
                "addressDetails": {
                    "forwardAddress": {
                        "contactDetails": {
                            "contactName": "str",
                            "emailList": ["str"],
                            "phone": "str",
                            "mobile": "str",
                            "phoneExtension": "str",
                        },
                        "addressValidationStatus": "str",
                        "shippingAddress": {
                            "country": "str",
                            "streetAddress1": "str",
                            "addressType": "str",
                            "city": "str",
                            "companyName": "str",
                            "postalCode": "str",
                            "stateOrProvince": "str",
                            "streetAddress2": "str",
                            "streetAddress3": "str",
                            "zipExtendedCode": "str",
                        },
                    },
                    "returnAddress": {
                        "contactDetails": {
                            "contactName": "str",
                            "emailList": ["str"],
                            "phone": "str",
                            "mobile": "str",
                            "phoneExtension": "str",
                        },
                        "addressValidationStatus": "str",
                        "shippingAddress": {
                            "country": "str",
                            "streetAddress1": "str",
                            "addressType": "str",
                            "city": "str",
                            "companyName": "str",
                            "postalCode": "str",
                            "stateOrProvince": "str",
                            "streetAddress2": "str",
                            "streetAddress3": "str",
                            "zipExtendedCode": "str",
                        },
                    },
                },
                "location": "str",
                "orderId": "str",
                "orderItemDetails": {
                    "orderItemType": "str",
                    "productDetails": {
                        "hierarchyInformation": {
                            "configurationName": "str",
                            "productFamilyName": "str",
                            "productLineName": "str",
                            "productName": "str",
                        },
                        "count": 0,
                        "deviceDetails": [
                            {"managementResourceId": "str", "managementResourceTenantId": "str", "serialNumber": "str"}
                        ],
                        "displayInfo": {"configurationDisplayName": "str", "productFamilyDisplayName": "str"},
                        "productDoubleEncryptionStatus": "str",
                    },
                    "cancellationReason": "str",
                    "cancellationStatus": "str",
                    "currentStage": {
                        "displayName": "str",
                        "stageName": "str",
                        "stageStatus": "str",
                        "startTime": "2020-02-20 00:00:00",
                    },
                    "deletionStatus": "str",
                    "error": {
                        "additionalInfo": [{"info": {}, "type": "str"}],
                        "code": "str",
                        "details": [...],
                        "message": "str",
                        "target": "str",
                    },
                    "forwardShippingDetails": {
                        "carrierDisplayName": "str",
                        "carrierName": "str",
                        "trackingId": "str",
                        "trackingUrl": "str",
                    },
                    "managementRpDetails": {"resourceProviderNamespace": "str"},
                    "managementRpDetailsList": [{"resourceProviderNamespace": "str"}],
                    "notificationEmailList": ["str"],
                    "orderItemStageHistory": [
                        {
                            "displayName": "str",
                            "stageName": "str",
                            "stageStatus": "str",
                            "startTime": "2020-02-20 00:00:00",
                        }
                    ],
                    "preferences": {
                        "encryptionPreferences": {"doubleEncryptionStatus": "str"},
                        "managementResourcePreferences": {"preferredManagementResourceId": "str"},
                        "notificationPreferences": [{"sendNotification": bool, "stageName": "str"}],
                        "transportPreferences": {"preferredShipmentType": "str"},
                    },
                    "returnReason": "str",
                    "returnStatus": "str",
                    "reverseShippingDetails": {
                        "carrierDisplayName": "str",
                        "carrierName": "str",
                        "sasKeyForLabel": "str",
                        "trackingId": "str",
                        "trackingUrl": "str",
                    },
                },
                "id": "str",
                "name": "str",
                "startTime": "2020-02-20 00:00:00",
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_delete_order_item_by_name(self, resource_group):
        response = self.client.begin_delete_order_item_by_name(
            order_item_name="str",
            resource_group_name=resource_group.name,
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_update_order_item(self, resource_group):
        response = self.client.begin_update_order_item(
            order_item_name="str",
            resource_group_name=resource_group.name,
            order_item_update_parameter={
                "forwardAddress": {
                    "contactDetails": {
                        "contactName": "str",
                        "emailList": ["str"],
                        "phone": "str",
                        "mobile": "str",
                        "phoneExtension": "str",
                    },
                    "addressValidationStatus": "str",
                    "shippingAddress": {
                        "country": "str",
                        "streetAddress1": "str",
                        "addressType": "str",
                        "city": "str",
                        "companyName": "str",
                        "postalCode": "str",
                        "stateOrProvince": "str",
                        "streetAddress2": "str",
                        "streetAddress3": "str",
                        "zipExtendedCode": "str",
                    },
                },
                "notificationEmailList": ["str"],
                "preferences": {
                    "encryptionPreferences": {"doubleEncryptionStatus": "str"},
                    "managementResourcePreferences": {"preferredManagementResourceId": "str"},
                    "notificationPreferences": [{"sendNotification": bool, "stageName": "str"}],
                    "transportPreferences": {"preferredShipmentType": "str"},
                },
                "tags": {"str": "str"},
            },
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_cancel_order_item(self, resource_group):
        response = self.client.cancel_order_item(
            order_item_name="str",
            resource_group_name=resource_group.name,
            cancellation_reason={"reason": "str"},
            api_version="2021-12-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_begin_return_order_item(self, resource_group):
        response = self.client.begin_return_order_item(
            order_item_name="str",
            resource_group_name=resource_group.name,
            return_order_item_details={
                "returnReason": "str",
                "returnAddress": {
                    "contactDetails": {
                        "contactName": "str",
                        "emailList": ["str"],
                        "phone": "str",
                        "mobile": "str",
                        "phoneExtension": "str",
                    },
                    "addressValidationStatus": "str",
                    "shippingAddress": {
                        "country": "str",
                        "streetAddress1": "str",
                        "addressType": "str",
                        "city": "str",
                        "companyName": "str",
                        "postalCode": "str",
                        "stateOrProvince": "str",
                        "streetAddress2": "str",
                        "streetAddress3": "str",
                        "zipExtendedCode": "str",
                    },
                },
                "serviceTag": "str",
                "shippingBoxRequired": False,
            },
            api_version="2021-12-01",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AbsoluteMarker(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """AbsoluteMarker."""

    ALL_BACKUP = "AllBackup"
    FIRST_OF_DAY = "FirstOfDay"
    FIRST_OF_MONTH = "FirstOfMonth"
    FIRST_OF_WEEK = "FirstOfWeek"
    FIRST_OF_YEAR = "FirstOfYear"


class AlertsState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """AlertsState."""

    ENABLED = "Enabled"
    DISABLED = "Disabled"


class BCDRSecurityLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Security Level of Backup Vault."""

    POOR = "Poor"
    FAIR = "Fair"
    GOOD = "Good"
    EXCELLENT = "Excellent"
    NOT_SUPPORTED = "NotSupported"


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of identity that created the resource."""

    USER = "User"
    APPLICATION = "Application"
    MANAGED_IDENTITY = "ManagedIdentity"
    KEY = "Key"


class CrossRegionRestoreState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """CrossRegionRestore state."""

    DISABLED = "Disabled"
    ENABLED = "Enabled"


class CrossSubscriptionRestoreState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """CrossSubscriptionRestore state."""

    DISABLED = "Disabled"
    PERMANENTLY_DISABLED = "PermanentlyDisabled"
    ENABLED = "Enabled"


class CurrentProtectionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the current protection state of the resource."""

    INVALID = "Invalid"
    NOT_PROTECTED = "NotProtected"
    CONFIGURING_PROTECTION = "ConfiguringProtection"
    PROTECTION_CONFIGURED = "ProtectionConfigured"
    BACKUP_SCHEDULES_SUSPENDED = "BackupSchedulesSuspended"
    RETENTION_SCHEDULES_SUSPENDED = "RetentionSchedulesSuspended"
    PROTECTION_STOPPED = "ProtectionStopped"
    PROTECTION_ERROR = "ProtectionError"
    CONFIGURING_PROTECTION_FAILED = "ConfiguringProtectionFailed"
    SOFT_DELETING = "SoftDeleting"
    SOFT_DELETED = "SoftDeleted"
    UPDATING_PROTECTION = "UpdatingProtection"


class DataStoreTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """type of datastore; Operational/Vault/Archive."""

    OPERATIONAL_STORE = "OperationalStore"
    VAULT_STORE = "VaultStore"
    ARCHIVE_STORE = "ArchiveStore"


class DayOfWeek(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """DayOfWeek."""

    FRIDAY = "Friday"
    MONDAY = "Monday"
    SATURDAY = "Saturday"
    SUNDAY = "Sunday"
    THURSDAY = "Thursday"
    TUESDAY = "Tuesday"
    WEDNESDAY = "Wednesday"


class EncryptionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Encryption state of the Backup Vault."""

    ENABLED = "Enabled"
    """CMK encryption is enabled on the Backup Vault"""
    DISABLED = "Disabled"
    """CMK encryption is disabled on the Backup Vault. User can not set this state once Encryption
    State is 'Enabled'."""
    INCONSISTENT = "Inconsistent"
    """CMK encryption is in inconsistent state on the Backup Vault. This state indicates that user
    needs to retry the encryption settings operation immediately to correct the state."""


class ExistingResourcePolicy(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the Conflict Policy property. This property sets policy during conflict of
    resources during restore.
    """

    SKIP = "Skip"
    PATCH = "Patch"


class FeatureSupportStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """feature support status."""

    INVALID = "Invalid"
    NOT_SUPPORTED = "NotSupported"
    ALPHA_PREVIEW = "AlphaPreview"
    PRIVATE_PREVIEW = "PrivatePreview"
    PUBLIC_PREVIEW = "PublicPreview"
    GENERALLY_AVAILABLE = "GenerallyAvailable"


class FeatureType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """backup support feature type."""

    INVALID = "Invalid"
    DATA_SOURCE_TYPE = "DataSourceType"


class IdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The identity type. 'SystemAssigned' and 'UserAssigned' are mutually exclusive. 'SystemAssigned'
    will use implicitly created managed identity.
    """

    SYSTEM_ASSIGNED = "SystemAssigned"
    USER_ASSIGNED = "UserAssigned"


class ImmutabilityState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Immutability state."""

    DISABLED = "Disabled"
    UNLOCKED = "Unlocked"
    LOCKED = "Locked"


class InfrastructureEncryptionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Enabling/Disabling the Double Encryption state."""

    ENABLED = "Enabled"
    DISABLED = "Disabled"


class Month(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Month."""

    APRIL = "April"
    AUGUST = "August"
    DECEMBER = "December"
    FEBRUARY = "February"
    JANUARY = "January"
    JULY = "July"
    JUNE = "June"
    MARCH = "March"
    MAY = "May"
    NOVEMBER = "November"
    OCTOBER = "October"
    SEPTEMBER = "September"


class PersistentVolumeRestoreMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the PV (Persistent Volume) Restore Mode property. This property sets whether
    volumes needs to be restored.
    """

    RESTORE_WITH_VOLUME_DATA = "RestoreWithVolumeData"
    RESTORE_WITHOUT_VOLUME_DATA = "RestoreWithoutVolumeData"


class ProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provisioning state of the BackupVault resource."""

    FAILED = "Failed"
    PROVISIONING = "Provisioning"
    SUCCEEDED = "Succeeded"
    UNKNOWN = "Unknown"
    UPDATING = "Updating"


class RecoveryOption(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Recovery Option."""

    FAIL_IF_EXISTS = "FailIfExists"


class RecoveryPointCompletionState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies recovery point completeness. Partial (i.e., only some of the intended items were
    backed up), or Completed (i.e., ALL intended items were backed up).
    """

    COMPLETED = "Completed"
    PARTIAL = "Partial"


class RehydrationPriority(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Priority to be used for rehydration. Values High or Standard."""

    INVALID = "Invalid"
    HIGH = "High"
    STANDARD = "Standard"


class RehydrationStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """RehydrationStatus."""

    CREATE_IN_PROGRESS = "CREATE_IN_PROGRESS"
    COMPLETED = "COMPLETED"
    DELETE_IN_PROGRESS = "DELETE_IN_PROGRESS"
    DELETED = "DELETED"
    FAILED = "FAILED"


class ResourceMoveState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Resource move state for backup vault."""

    UNKNOWN = "Unknown"
    IN_PROGRESS = "InProgress"
    PREPARE_FAILED = "PrepareFailed"
    COMMIT_FAILED = "CommitFailed"
    FAILED = "Failed"
    PREPARE_TIMEDOUT = "PrepareTimedout"
    COMMIT_TIMEDOUT = "CommitTimedout"
    CRITICAL_FAILURE = "CriticalFailure"
    PARTIAL_SUCCESS = "PartialSuccess"
    MOVE_SUCCEEDED = "MoveSucceeded"


class ResourcePropertiesObjectType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of the specific object - used for deserializing."""

    DEFAULT_RESOURCE_PROPERTIES = "DefaultResourceProperties"


class RestoreSourceDataStoreType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the type of the source data store."""

    OPERATIONAL_STORE = "OperationalStore"
    VAULT_STORE = "VaultStore"
    ARCHIVE_STORE = "ArchiveStore"


class RestoreTargetLocationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Denotes the target location where the data will be restored,
    string value for the enum
    {Microsoft.Internal.AzureBackup.DataProtection.Common.Interface.RestoreTargetLocationType}.
    """

    INVALID = "Invalid"
    AZURE_BLOBS = "AzureBlobs"
    AZURE_FILES = "AzureFiles"


class SecretStoreType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the type of secret store."""

    INVALID = "Invalid"
    AZURE_KEY_VAULT = "AzureKeyVault"


class SecureScoreLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Secure Score of Backup Vault."""

    NONE = "None"
    MINIMUM = "Minimum"
    ADEQUATE = "Adequate"
    MAXIMUM = "Maximum"
    NOT_SUPPORTED = "NotSupported"


class SoftDeleteState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of soft delete."""

    OFF = "Off"
    """Soft Delete is turned off for the BackupVault"""
    ON = "On"
    """Soft Delete is enabled for the BackupVault but can be turned off"""
    ALWAYS_ON = "AlwaysOn"
    """Soft Delete is permanently enabled for the BackupVault and the setting cannot be changed"""


class SourceDataStoreType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the type of the source data store."""

    ARCHIVE_STORE = "ArchiveStore"
    SNAPSHOT_STORE = "SnapshotStore"
    OPERATIONAL_STORE = "OperationalStore"
    VAULT_STORE = "VaultStore"


class Status(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the protection status of the resource."""

    CONFIGURING_PROTECTION = "ConfiguringProtection"
    CONFIGURING_PROTECTION_FAILED = "ConfiguringProtectionFailed"
    PROTECTION_CONFIGURED = "ProtectionConfigured"
    PROTECTION_STOPPED = "ProtectionStopped"
    SOFT_DELETED = "SoftDeleted"
    SOFT_DELETING = "SoftDeleting"


class StorageSettingStoreTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the type of the datastore."""

    ARCHIVE_STORE = "ArchiveStore"
    OPERATIONAL_STORE = "OperationalStore"
    VAULT_STORE = "VaultStore"


class StorageSettingTypes(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Gets or sets the type."""

    GEO_REDUNDANT = "GeoRedundant"
    LOCALLY_REDUNDANT = "LocallyRedundant"
    ZONE_REDUNDANT = "ZoneRedundant"


class SyncType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Field indicating sync type e.g. to sync only in case of failure or in all cases."""

    DEFAULT = "Default"
    FORCE_RESYNC = "ForceResync"


class ValidationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the type of validation. In case of DeepValidation, all validations from
    /validateForBackup API will run again.
    """

    SHALLOW_VALIDATION = "ShallowValidation"
    DEEP_VALIDATION = "DeepValidation"


class WeekNumber(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """WeekNumber."""

    FIRST = "First"
    FOURTH = "Fourth"
    LAST = "Last"
    SECOND = "Second"
    THIRD = "Third"



# coding=utf-8
# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
from azure.ai.language.questionanswering.authoring import AuthoringClient
from azure.core.credentials import AzureKeyCredential

from helpers import QnaAuthoringHelper
from testcase import QuestionAnsweringTestCase


class TestExportAndImport(QuestionAnsweringTestCase):

    def test_export_project(self, recorded_test, qna_creds):
        client = AuthoringClient(qna_creds["qna_endpoint"], AzureKeyCredential(qna_creds["qna_key"]))

        # create project
        project_name = "IssacNewton"
        QnaAuthoringHelper.create_test_project(client, project_name=project_name, **self.kwargs_for_polling)

        # export project
        export_poller = client.begin_export(
            project_name=project_name,
            file_format="json",
            **self.kwargs_for_polling
        )
        result = export_poller.result()
        assert result["status"] == "succeeded"
        assert result["resultUrl"] is not None

    def test_import_project(self, recorded_test, qna_creds):
        client = AuthoringClient(qna_creds["qna_endpoint"], AzureKeyCredential(qna_creds["qna_key"]))

        # create project
        project_name = "IssacNewton"
        export_url = QnaAuthoringHelper.create_test_project(
            client,
            project_name=project_name,
            get_export_url=True,
            delete_old_project=True,
            **self.kwargs_for_polling
        )

        # import project
        project = {
            "Metadata": {
                "ProjectName": project_name,
                "Description": "biography of Sir Issac Newton",
                "Language": "en",
                "MultilingualResource": False,
                "Settings": {
                    "DefaultAnswer": "no answer"
                }
            }
        }
        import_poller = client.begin_import_assets(
            project_name=project_name,
            options=project,
            **self.kwargs_for_polling
        )
        job_state = import_poller.result()
        assert job_state["jobId"]

        # assert
        project_found = False
        projects = client.list_projects()
        for p in projects:
            if ("projectName" in p) and p["projectName"] == project_name:
                project_found = True
        assert project_found



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.databoxedge.aio import DataBoxEdgeManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer
from devtools_testutils.aio import recorded_by_proxy_async

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestDataBoxEdgeManagementOrdersOperationsAsync(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(DataBoxEdgeManagementClient, is_async=True)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_orders_list_by_data_box_edge_device(self, resource_group):
        response = self.client.orders.list_by_data_box_edge_device(
            device_name="str",
            resource_group_name=resource_group.name,
            api_version="2019-08-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_orders_get(self, resource_group):
        response = await self.client.orders.get(
            device_name="str",
            resource_group_name=resource_group.name,
            api_version="2019-08-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_orders_begin_create_or_update(self, resource_group):
        response = await (
            await self.client.orders.begin_create_or_update(
                device_name="str",
                resource_group_name=resource_group.name,
                order={
                    "contactInformation": {
                        "companyName": "str",
                        "contactPerson": "str",
                        "emailList": ["str"],
                        "phone": "str",
                    },
                    "currentStatus": {
                        "status": "str",
                        "additionalOrderDetails": {"str": "str"},
                        "comments": "str",
                        "updateDateTime": "2020-02-20 00:00:00",
                    },
                    "deliveryTrackingInfo": [
                        {"carrierName": "str", "serialNumber": "str", "trackingId": "str", "trackingUrl": "str"}
                    ],
                    "id": "str",
                    "name": "str",
                    "orderHistory": [
                        {
                            "status": "str",
                            "additionalOrderDetails": {"str": "str"},
                            "comments": "str",
                            "updateDateTime": "2020-02-20 00:00:00",
                        }
                    ],
                    "returnTrackingInfo": [
                        {"carrierName": "str", "serialNumber": "str", "trackingId": "str", "trackingUrl": "str"}
                    ],
                    "serialNumber": "str",
                    "shippingAddress": {
                        "addressLine1": "str",
                        "city": "str",
                        "country": "str",
                        "postalCode": "str",
                        "state": "str",
                        "addressLine2": "str",
                        "addressLine3": "str",
                    },
                    "type": "str",
                },
                api_version="2019-08-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_orders_begin_delete(self, resource_group):
        response = await (
            await self.client.orders.begin_delete(
                device_name="str",
                resource_group_name=resource_group.name,
                api_version="2019-08-01",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class JobErrorItem(Model):
    """The job error items.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar recommendations: The recommended actions.
    :vartype recommendations: list[str]
    :ivar code: The code intended for programmatic access.
    :vartype code: str
    :ivar message: The message that describes the error in detail.
    :vartype message: str
    """

    _validation = {
        'recommendations': {'readonly': True},
        'code': {'readonly': True},
        'message': {'readonly': True},
    }

    _attribute_map = {
        'recommendations': {'key': 'recommendations', 'type': '[str]'},
        'code': {'key': 'code', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(JobErrorItem, self).__init__(**kwargs)
        self.recommendations = None
        self.code = None
        self.message = None



# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
"""Tests for the request id policy."""
from azure.core.pipeline.policies import RequestIdPolicy
from azure.core.pipeline import PipelineRequest, PipelineContext

try:
    from unittest import mock
except ImportError:
    import mock
from itertools import product
import pytest
from utils import HTTP_REQUESTS

auto_request_id_values = (True, False, None)
request_id_init_values = ("foo", None, "_unset")
request_id_set_values = ("bar", None, "_unset")
request_id_req_values = ("baz", None, "_unset")
request_id_header_name_values = ("client-request-id", "_unset")
full_combination = list(
    product(
        auto_request_id_values,
        request_id_init_values,
        request_id_set_values,
        request_id_req_values,
        request_id_header_name_values,
        HTTP_REQUESTS,
    )
)


@pytest.mark.parametrize(
    "auto_request_id, request_id_init, request_id_set, request_id_req, request_id_header_name, http_request",
    full_combination,
)
def test_request_id_policy(
    auto_request_id, request_id_init, request_id_set, request_id_req, request_id_header_name, http_request
):
    """Test policy with no other policy and happy path"""
    kwargs = {}
    if request_id_header_name != "_unset":
        kwargs["request_id_header_name"] = request_id_header_name
    if auto_request_id is not None:
        kwargs["auto_request_id"] = auto_request_id
    if request_id_init != "_unset":
        kwargs["request_id"] = request_id_init
    request_id_policy = RequestIdPolicy(**kwargs)
    if request_id_set != "_unset":
        request_id_policy.set_request_id(request_id_set)
    request = http_request("GET", "http://localhost/")
    pipeline_request = PipelineRequest(request, PipelineContext(None))
    if request_id_req != "_unset":
        pipeline_request.context.options["request_id"] = request_id_req
    with mock.patch("uuid.uuid1", return_value="VALUE"):
        request_id_policy.on_request(pipeline_request)

    assert all(v is not None for v in request.headers.values())
    expected_header_name = "x-ms-client-request-id" if request_id_header_name == "_unset" else "client-request-id"
    if request_id_req != "_unset" and request_id_req:
        assert request.headers[expected_header_name] == request_id_req
    elif not request_id_req:
        assert not expected_header_name in request.headers
    elif request_id_set != "_unset" and request_id_set:
        assert request.headers[expected_header_name] == request_id_set
    elif not request_id_set:
        assert not expected_header_name in request.headers
    elif request_id_init != "_unset" and request_id_init:
        assert request.headers[expected_header_name] == request_id_init
    elif not request_id_init:
        assert not expected_header_name in request.headers
    elif auto_request_id or auto_request_id is None:
        assert request.headers[expected_header_name] == "VALUE"
    else:
        assert not expected_header_name in request.headers


@pytest.mark.parametrize("http_request", HTTP_REQUESTS)
def test_request_id_already_exists(http_request):
    """Test policy with no other policy and happy path"""
    request_id_policy = RequestIdPolicy()
    request = http_request("GET", "http://localhost/")
    request.headers["x-ms-client-request-id"] = "VALUE"
    pipeline_request = PipelineRequest(request, PipelineContext(None))
    request_id_policy.on_request(pipeline_request)
    assert request.headers["x-ms-client-request-id"] == "VALUE"



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.containerservice.v2025_03_01.aio import ContainerServiceClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer
from devtools_testutils.aio import recorded_by_proxy_async

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestContainerServiceSnapshotsOperationsAsync(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(ContainerServiceClient, is_async=True)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_list(self, resource_group):
        response = self.client.snapshots.list(
            api_version="2025-03-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_list_by_resource_group(self, resource_group):
        response = self.client.snapshots.list_by_resource_group(
            resource_group_name=resource_group.name,
            api_version="2025-03-01",
        )
        result = [r async for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_get(self, resource_group):
        response = await self.client.snapshots.get(
            resource_group_name=resource_group.name,
            resource_name="str",
            api_version="2025-03-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_create_or_update(self, resource_group):
        response = await self.client.snapshots.create_or_update(
            resource_group_name=resource_group.name,
            resource_name="str",
            parameters={
                "location": "str",
                "creationData": {"sourceResourceId": "str"},
                "enableFIPS": bool,
                "id": "str",
                "kubernetesVersion": "str",
                "name": "str",
                "nodeImageVersion": "str",
                "osSku": "str",
                "osType": "Linux",
                "snapshotType": "NodePool",
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
                "vmSize": "str",
            },
            api_version="2025-03-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_update_tags(self, resource_group):
        response = await self.client.snapshots.update_tags(
            resource_group_name=resource_group.name,
            resource_name="str",
            parameters={"tags": {"str": "str"}},
            api_version="2025-03-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_snapshots_delete(self, resource_group):
        response = await self.client.snapshots.delete(
            resource_group_name=resource_group.name,
            resource_name="str",
            api_version="2025-03-01",
        )

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models import AlignPolicy
from ._models import AnomalyDetectionModel
from ._models import AnomalyDetectorError
from ._models import AnomalyInterpretation
from ._models import AnomalyState
from ._models import AnomalyValue
from ._models import CorrelationChanges
from ._models import DiagnosticsInfo
from ._models import ErrorResponse
from ._models import ModelInfo
from ._models import ModelState
from ._models import MultivariateBatchDetectionOptions
from ._models import MultivariateBatchDetectionResultSummary
from ._models import MultivariateDetectionResult
from ._models import MultivariateLastDetectionOptions
from ._models import MultivariateLastDetectionResult
from ._models import ResponseError
from ._models import TimeSeriesPoint
from ._models import UnivariateChangePointDetectionOptions
from ._models import UnivariateChangePointDetectionResult
from ._models import UnivariateDetectionOptions
from ._models import UnivariateEntireDetectionResult
from ._models import UnivariateLastDetectionResult
from ._models import VariableState
from ._models import VariableValues

from ._enums import APIVersion
from ._enums import AlignMode
from ._enums import AnomalyDetectorErrorCodes
from ._enums import DataSchema
from ._enums import FillNAMethod
from ._enums import ImputeMode
from ._enums import ModelStatus
from ._enums import MultivariateBatchDetectionStatus
from ._enums import TimeGranularity
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AlignPolicy",
    "AnomalyDetectionModel",
    "AnomalyDetectorError",
    "AnomalyInterpretation",
    "AnomalyState",
    "AnomalyValue",
    "CorrelationChanges",
    "DiagnosticsInfo",
    "ErrorResponse",
    "ModelInfo",
    "ModelState",
    "MultivariateBatchDetectionOptions",
    "MultivariateBatchDetectionResultSummary",
    "MultivariateDetectionResult",
    "MultivariateLastDetectionOptions",
    "MultivariateLastDetectionResult",
    "ResponseError",
    "TimeSeriesPoint",
    "UnivariateChangePointDetectionOptions",
    "UnivariateChangePointDetectionResult",
    "UnivariateDetectionOptions",
    "UnivariateEntireDetectionResult",
    "UnivariateLastDetectionResult",
    "VariableState",
    "VariableValues",
    "APIVersion",
    "AlignMode",
    "AnomalyDetectorErrorCodes",
    "DataSchema",
    "FillNAMethod",
    "ImputeMode",
    "ModelStatus",
    "MultivariateBatchDetectionStatus",
    "TimeGranularity",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()



from python import python_process
from go import go_process
from java import java_process
from js import js_process
from common import Common

import os
import logging

logging.basicConfig(level=logging.INFO,
                    format='%(funcName)s[line:%(lineno)d] - %(levelname)s: %(message)s')
_LOG = logging.getLogger(__name__)

_LANGUAGES = {
    'python': python_process,
    'java': java_process,
    'go': go_process,
    'js': js_process
}


def main():
    language = os.getenv('LANGUAGE')
    languages = {language: _LANGUAGES[language]} if language in _LANGUAGES.keys() else _LANGUAGES
    for language in languages:
        try:
            languages[language]()
        except Exception as e:
            _LOG.info(f'Failed to collect issues status for {language}: {e}')
    Common.push_md_to_storage()


if __name__ == '__main__':
    main()



# The MIT License (MIT)
# Copyright (c) 2014 Microsoft Corporation

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Create, read, update and delete and execute scripts in the Azure Cosmos DB SQL API service.
"""

from typing import Any, Dict, List, Mapping, Union, Optional, Type, Sequence

from azure.core.paging import ItemPaged
from azure.core.tracing.decorator import distributed_trace

from ._cosmos_client_connection import CosmosClientConnection
from ._base import build_options
from .partition_key import NonePartitionKeyValue, _return_undefined_or_empty_partition_key

# pylint: disable=protected-access
# pylint: disable=missing-client-constructor-parameter-credential,missing-client-constructor-parameter-kwargs

PartitionKeyType = Union[str, int, float, bool, Sequence[Union[str, int, float, bool, None]], Type[NonePartitionKeyValue]]  # pylint: disable=line-too-long


class ScriptType:
    StoredProcedure = "sprocs"
    Trigger = "triggers"
    UserDefinedFunction = "udfs"


class ScriptsProxy:
    """An interface to interact with stored procedures.

    This class should not be instantiated directly. Instead, use the
    :func:`ContainerProxy.scripts` attribute.
    """

    def __init__(
        self,
        client_connection: CosmosClientConnection,
        container_link: str,
        is_system_key: bool
    ) -> None:
        self.client_connection = client_connection
        self.container_link = container_link
        self.is_system_key = is_system_key

    def _get_resource_link(self, script_or_id: Union[str, Mapping[str, Any]], typ: str) -> str:
        if isinstance(script_or_id, str):
            return "{}/{}/{}".format(self.container_link, typ, script_or_id)
        return script_or_id["_self"]

    @distributed_trace
    def list_stored_procedures(
        self,
        max_item_count: Optional[int] = None,
        **kwargs: Any
    ) -> ItemPaged[Dict[str, Any]]:
        """List all stored procedures in the container.

        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of stored procedures (dicts).
        :rtype: Iterable[dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count

        return self.client_connection.ReadStoredProcedures(
            collection_link=self.container_link, options=feed_options, **kwargs
        )

    @distributed_trace
    def query_stored_procedures(
        self,
        query: str,
        parameters: Optional[List[Dict[str, Any]]] = None,
        max_item_count: Optional[int] = None,
        **kwargs: Any
    ) -> ItemPaged[Dict[str, Any]]:
        """Return all stored procedures matching the given `query`.

        :param str query: The Azure Cosmos DB SQL query to execute.
        :param parameters: Optional array of parameters to the query. Ignored if no query is provided.
        :type parameters: List[Dict[str, Any]]
        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of stored procedures (dicts).
        :rtype: Iterable[Dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count
        return self.client_connection.QueryStoredProcedures(
            collection_link=self.container_link,
            query=query if parameters is None else {"query": query, "parameters": parameters},
            options=feed_options,
            **kwargs
        )

    @distributed_trace
    def get_stored_procedure(self, sproc: Union[str, Mapping[str, Any]], **kwargs: Any) -> Dict[str, Any]:
        """Get the stored procedure identified by `id`.

        :param sproc: The ID (name) or dict representing stored procedure to retrieve.
        :type sproc: Union[str, Dict[str, Any]]
        :returns: A dict representing the retrieved stored procedure.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the given stored procedure couldn't be retrieved.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)

        return self.client_connection.ReadStoredProcedure(
            sproc_link=self._get_resource_link(sproc, ScriptType.StoredProcedure), options=request_options, **kwargs
        )

    @distributed_trace
    def create_stored_procedure(self, body: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
        """Create a new stored procedure in the container.

        To replace an existing sproc, use the :func:`Container.scripts.replace_stored_procedure` method.

        :param Dict[str, Any] body: A dict-like object representing the sproc to create.
        :returns: A dict representing the new stored procedure.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the given stored procedure couldn't be created.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)

        return self.client_connection.CreateStoredProcedure(
            collection_link=self.container_link, sproc=body, options=request_options, **kwargs
        )

    @distributed_trace
    def replace_stored_procedure(
        self,
        sproc: Union[str, Mapping[str, Any]],
        body: Dict[str, Any],
        **kwargs: Any
    ) -> Dict[str, Any]:
        """Replace a specified stored procedure in the container.

        If the stored procedure does not already exist in the container, an exception is raised.

        :param sproc: The ID (name) or dict representing stored procedure to be replaced.
        :type sproc: Union[str, Dict[str, Any]]
        :param Dict[str, Any] body: A dict-like object representing the sproc to replace.
        :returns: A dict representing the stored procedure after replace went through.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the replace operation failed or the stored
            procedure with given id does not exist.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)
        return self.client_connection.ReplaceStoredProcedure(
            sproc_link=self._get_resource_link(sproc, ScriptType.StoredProcedure),
            sproc=body,
            options=request_options,
            **kwargs
        )

    @distributed_trace
    def delete_stored_procedure(self, sproc: Union[str, Mapping[str, Any]], **kwargs: Any) -> None:
        """Delete a specified stored procedure from the container.

        If the stored procedure does not already exist in the container, an exception is raised.

        :param sproc: The ID (name) or dict representing stored procedure to be deleted.
        :type sproc: Union[str, Dict[str, Any]]
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: The sproc wasn't deleted successfully.
        :raises ~azure.cosmos.exceptions.CosmosResourceNotFoundError: The sproc does not exist in the container.
        :rtype: None
        """
        request_options = build_options(kwargs)
        self.client_connection.DeleteStoredProcedure(
            sproc_link=self._get_resource_link(sproc, ScriptType.StoredProcedure), options=request_options, **kwargs
        )

    @distributed_trace
    def execute_stored_procedure(
        self,
        sproc: Union[str, Mapping[str, Any]],
        partition_key: Optional[PartitionKeyType] = None,
        params: Optional[List[Dict[str, Any]]] = None,
        enable_script_logging: Optional[bool] = None,
        **kwargs: Any
    ) -> Dict[str, Any]:
        """Execute a specified stored procedure.

        If the stored procedure does not already exist in the container, an exception is raised.

        :param sproc: The ID (name) or dict representing stored procedure to be executed.
        :type sproc: Union[str, Dict[str, Any]]
        :param partition_key: Specifies the partition key to indicate which partition the sproc should execute on.
        :type partition_key: Union[str, int, float, bool]
        :param params: List of parameters to be passed to the stored procedure to be executed.
        :type params: List[Dict[str, Any]]
        :param bool enable_script_logging: Enables or disables script logging for the current request.
        :returns: Result of the executed stored procedure for the given parameters.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the stored procedure execution failed
            or if the stored procedure with given id does not exist in the container.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)
        if partition_key is not None:
            request_options["partitionKey"] = (
                _return_undefined_or_empty_partition_key(self.is_system_key)
                if partition_key == NonePartitionKeyValue
                else partition_key
            )
        if enable_script_logging is not None:
            request_options["enableScriptLogging"] = enable_script_logging

        return self.client_connection.ExecuteStoredProcedure(
            sproc_link=self._get_resource_link(sproc, ScriptType.StoredProcedure),
            params=params,
            options=request_options,
            **kwargs
        )

    @distributed_trace
    def list_triggers(self, max_item_count: Optional[int] = None, **kwargs: Any) -> ItemPaged[Dict[str, Any]]:
        """List all triggers in the container.

        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of triggers (dicts).
        :rtype: Iterable[Dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count

        return self.client_connection.ReadTriggers(
            collection_link=self.container_link, options=feed_options, **kwargs
        )

    @distributed_trace
    def query_triggers(
        self,
        query: str,
        parameters: Optional[List[Dict[str, Any]]] = None,
        max_item_count: Optional[int] = None,
        **kwargs: Any
    ) -> ItemPaged[Dict[str, Any]]:
        """Return all triggers matching the given `query`.

        :param str query: The Azure Cosmos DB SQL query to execute.
        :param parameters: Optional array of parameters to the query. Ignored if no query is provided.
        :type parameters: List[Dict[str, Any]]
        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of triggers (dicts).
        :rtype: Iterable[dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count

        return self.client_connection.QueryTriggers(
            collection_link=self.container_link,
            query=query if parameters is None else {"query": query, "parameters": parameters},
            options=feed_options,
            **kwargs
        )

    @distributed_trace
    def get_trigger(self, trigger: Union[str, Mapping[str, Any]], **kwargs: Any) -> Dict[str, Any]:
        """Get a trigger identified by `id`.

        :param trigger: The ID (name) or dict representing trigger to retrieve.
        :type trigger: Union[str, Dict[str, Any]]
        :returns: A dict representing the retrieved trigger.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the given trigger couldn't be retrieved.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)

        return self.client_connection.ReadTrigger(
            trigger_link=self._get_resource_link(trigger, ScriptType.Trigger), options=request_options, **kwargs
        )

    @distributed_trace
    def create_trigger(self, body: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
        """Create a trigger in the container.

        To replace an existing trigger, use the :func:`ContainerProxy.scripts.replace_trigger` method.

        :param Dict[str, Any] body: A dict-like object representing the trigger to create.
        :returns: A dict representing the new trigger.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the given trigger couldn't be created.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)
        return self.client_connection.CreateTrigger(
            collection_link=self.container_link, trigger=body, options=request_options, **kwargs
        )

    @distributed_trace
    def replace_trigger(
        self,
        trigger: Union[str, Mapping[str, Any]],
        body: Dict[str, Any],
        **kwargs: Any
    ) -> Dict[str, Any]:
        """Replace a specified trigger in the container.

        If the trigger does not already exist in the container, an exception is raised.

        :param trigger: The ID (name) or dict representing trigger to be replaced.
        :type trigger: Union[str, Dict[str, Any]]
        :param Dict[str, Any] body: A dict-like object representing the trigger to replace.
        :returns: A dict representing the trigger after replace went through.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the replace operation failed or the trigger
            with given id does not exist.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)

        return self.client_connection.ReplaceTrigger(
            trigger_link=self._get_resource_link(trigger, ScriptType.Trigger),
            trigger=body,
            options=request_options,
            **kwargs
        )

    @distributed_trace
    def delete_trigger(self, trigger: Union[str, Mapping[str, Any]], **kwargs: Any) -> None:
        """Delete a specified trigger from the container.

        If the trigger does not already exist in the container, an exception is raised.

        :param trigger: The ID (name) or dict representing trigger to be deleted.
        :type trigger: Union[str, Dict[str, Any]]
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: The trigger wasn't deleted successfully.
        :raises ~azure.cosmos.exceptions.CosmosResourceNotFoundError: The trigger does not exist in the container.
        :rtype: None
        """
        request_options = build_options(kwargs)
        self.client_connection.DeleteTrigger(
            trigger_link=self._get_resource_link(trigger, ScriptType.Trigger), options=request_options, **kwargs
        )

    @distributed_trace
    def list_user_defined_functions(
        self,
        max_item_count: Optional[int] = None,
        **kwargs: Any
    ) -> ItemPaged[Dict[str, Any]]:
        """List all the user-defined functions in the container.

        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of user-defined functions (dicts).
        :rtype: Iterable[Dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count

        return self.client_connection.ReadUserDefinedFunctions(
            collection_link=self.container_link, options=feed_options, **kwargs
        )

    @distributed_trace
    def query_user_defined_functions(
        self,
        query: str,
        parameters: Optional[List[Dict[str, Any]]] = None,
        max_item_count: Optional[int] = None,
        **kwargs: Any
    ) -> ItemPaged[Dict[str, Any]]:
        """Return user-defined functions matching a given `query`.

        :param str query: The Azure Cosmos DB SQL query to execute.
        :param parameters: Optional array of parameters to the query. Ignored if no query is provided.
        :type parameters: List[Dict[str, Any]]
        :param int max_item_count: Max number of items to be returned in the enumeration operation.
        :returns: An Iterable of user-defined functions (dicts).
        :rtype: Iterable[Dict[str, Any]]
        """
        feed_options = build_options(kwargs)
        if max_item_count is not None:
            feed_options["maxItemCount"] = max_item_count

        return self.client_connection.QueryUserDefinedFunctions(
            collection_link=self.container_link,
            query=query if parameters is None else {"query": query, "parameters": parameters},
            options=feed_options,
            **kwargs
        )

    @distributed_trace
    def get_user_defined_function(self, udf: Union[str, Mapping[str, Any]], **kwargs: Any) -> Dict[str, Any]:
        """Get a user-defined functions identified by `id`.

        :param udf: The ID (name) or dict representing udf to retrieve.
        :type udf: Union[str, Dict[str, Any]]
        :returns: A dict representing the retrieved user-defined function.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the user-defined function couldn't be retrieved.
        :rtype: Iterable[Dict[str, Any]]
        """
        request_options = build_options(kwargs)
        return self.client_connection.ReadUserDefinedFunction(
            udf_link=self._get_resource_link(udf, ScriptType.UserDefinedFunction), options=request_options, **kwargs
        )

    @distributed_trace
    def create_user_defined_function(self, body: Dict[str, Any], **kwargs: Any) -> Dict[str, Any]:
        """Create a user-defined function in the container.

        To replace an existing UDF, use the :func:`ContainerProxy.scripts.replace_user_defined_function` method.

        :param Dict[str, Any] body: A dict-like object representing the udf to create.
        :returns: A dict representing the new user-defined function.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the user-defined function couldn't be created.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)
        return self.client_connection.CreateUserDefinedFunction(
            collection_link=self.container_link, udf=body, options=request_options, **kwargs
        )

    @distributed_trace
    def replace_user_defined_function(
        self,
        udf: Union[str, Mapping[str, Any]],
        body: Dict[str, Any],
        **kwargs: Any
    ) -> Dict[str, Any]:
        """Replace a specified user-defined function in the container.

        If the UDF does not already exist in the container, an exception is raised.

        :param udf: The ID (name) or dict representing udf to be replaced.
        :type udf: Union[str, Dict[str, Any]]
        :param Dict[str, Any] body: A dict-like object representing the udf to replace.
        :returns: A dict representing the user-defined function after replace went through.
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: If the replace operation failed or the user-defined
            function with the given id does not exist.
        :rtype: Dict[str, Any]
        """
        request_options = build_options(kwargs)
        return self.client_connection.ReplaceUserDefinedFunction(
            udf_link=self._get_resource_link(udf, ScriptType.UserDefinedFunction),
            udf=body,
            options=request_options,
            **kwargs
        )

    @distributed_trace
    def delete_user_defined_function(self, udf: Union[str, Mapping[str, Any]], **kwargs: Any) -> None:
        """Delete a specified user-defined function from the container.

        If the UDF does not already exist in the container, an exception is raised.

        :param udf: The ID (name) or dict representing udf to be deleted.
        :type udf: Union[str, Dict[str, Any]]
        :raises ~azure.cosmos.exceptions.CosmosHttpResponseError: The udf wasn't deleted successfully.
        :raises ~azure.cosmos.exceptions.CosmosResourceNotFoundError: The UDF does not exist in the container.
        :rtype: None
        """
        request_options = build_options(kwargs)
        self.client_connection.DeleteUserDefinedFunction(
            udf_link=self._get_resource_link(udf, ScriptType.UserDefinedFunction), options=request_options, **kwargs
        )



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential
from azure.mgmt.confluent import ConfluentManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-confluent
# USAGE
    python validations_validate_organizations.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = ConfluentManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="00000000-0000-0000-0000-000000000000",
    )

    response = client.validations.validate_organization(
        resource_group_name="myResourceGroup",
        organization_name="myOrganization",
        body={
            "location": "West US",
            "properties": {
                "offerDetail": {
                    "id": "string",
                    "planId": "string",
                    "planName": "string",
                    "privateOfferId": "string",
                    "privateOfferIds": ["string"],
                    "publisherId": "string",
                    "termUnit": "string",
                },
                "userDetail": {
                    "aadEmail": "abc@microsoft.com",
                    "emailAddress": "abc@microsoft.com",
                    "firstName": "string",
                    "lastName": "string",
                    "userPrincipalName": "abc@microsoft.com",
                },
            },
            "tags": {"Environment": "Dev"},
        },
    )
    print(response)


# x-ms-original-file: specification/confluent/resource-manager/Microsoft.Confluent/stable/2024-02-13/examples/Validations_ValidateOrganizations.json
if __name__ == "__main__":
    main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._eligible_child_resources_operations import EligibleChildResourcesOperations
from ._role_assignment_schedules_operations import RoleAssignmentSchedulesOperations
from ._role_assignment_schedule_instances_operations import RoleAssignmentScheduleInstancesOperations
from ._role_assignment_schedule_requests_operations import RoleAssignmentScheduleRequestsOperations
from ._role_eligibility_schedules_operations import RoleEligibilitySchedulesOperations
from ._role_eligibility_schedule_instances_operations import RoleEligibilityScheduleInstancesOperations
from ._role_eligibility_schedule_requests_operations import RoleEligibilityScheduleRequestsOperations
from ._role_management_policies_operations import RoleManagementPoliciesOperations
from ._role_management_policy_assignments_operations import RoleManagementPolicyAssignmentsOperations

from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "EligibleChildResourcesOperations",
    "RoleAssignmentSchedulesOperations",
    "RoleAssignmentScheduleInstancesOperations",
    "RoleAssignmentScheduleRequestsOperations",
    "RoleEligibilitySchedulesOperations",
    "RoleEligibilityScheduleInstancesOperations",
    "RoleEligibilityScheduleRequestsOperations",
    "RoleManagementPoliciesOperations",
    "RoleManagementPolicyAssignmentsOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.edgeorder import EdgeOrderManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-edgeorder
# USAGE
    python create_address.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = EdgeOrderManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="YourSubscriptionId",
    )

    response = client.begin_create_address(
        address_name="TestAddressName2",
        resource_group_name="YourResourceGroupName",
        address_resource={
            "location": "eastus",
            "properties": {
                "contactDetails": {
                    "contactName": "XXXX XXXX",
                    "emailList": ["xxxx@xxxx.xxx"],
                    "phone": "0000000000",
                    "phoneExtension": "",
                },
                "shippingAddress": {
                    "addressType": "None",
                    "city": "San Francisco",
                    "companyName": "Microsoft",
                    "country": "US",
                    "postalCode": "94107",
                    "stateOrProvince": "CA",
                    "streetAddress1": "16 TOWNSEND ST",
                    "streetAddress2": "UNIT 1",
                },
            },
        },
    ).result()
    print(response)


# x-ms-original-file: specification/edgeorder/resource-manager/Microsoft.EdgeOrder/stable/2021-12-01/examples/CreateAddress.json
if __name__ == "__main__":
    main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: sample_analyze_custom_documents.py

DESCRIPTION:
    This sample demonstrates how to analyze a document with a custom
    built model. The document must be of the same type as the documents the custom model
    was built on. To learn how to build your own models, look at
    sample_build_model.py.

USAGE:
    python sample_analyze_custom_documents.py

    Set the environment variables with your own values before running the sample:
    1) DOCUMENTINTELLIGENCE_ENDPOINT - the endpoint to your Document Intelligence resource.
    2) DOCUMENTINTELLIGENCE_API_KEY - your Document Intelligence API key.
    3) CUSTOM_BUILT_MODEL_ID - the ID of your custom built model.
        -OR-
       DOCUMENTINTELLIGENCE_STORAGE_ADVANCED_CONTAINER_SAS_URL - The shared access signature (SAS) Url of your Azure Blob Storage container with your training files.
       A model will be built and used to run the sample.
"""

import os
from collections import Counter


def analyze_custom_documents(custom_model_id):
    # For the Form_1.jpg, it should be the test file under the traning dataset which storage at the Azure Blob Storage path
    # combined by DOCUMENTINTELLIGENCE_STORAGE_ADVANCED_CONTAINER_SAS_URL and DOCUMENTINTELLIGENCE_STORAGE_PREFIX,
    # or it can also be a test file with the format similar to the training dataset.
    # Put it here locally just for presenting documents visually in sample.

    # Before analyzing a custom document, should upload the related training dataset into Azure Storage Blob and
    # train a model. For more information, see https://aka.ms/build-a-custom-model.
    path_to_sample_documents = os.path.abspath(
        os.path.join(os.path.abspath(__file__), "..", "./sample_forms/forms/Form_1.jpg")
    )
    # [START analyze_custom_documents]
    from azure.core.credentials import AzureKeyCredential
    from azure.ai.documentintelligence import DocumentIntelligenceClient
    from azure.ai.documentintelligence.models import AnalyzeResult

    def _print_table(header_names, table_data):
        # Print a two-dimensional array like a table.
        max_len_list = []
        for i in range(len(header_names)):
            col_values = list(map(lambda row: len(str(row[i])), table_data))
            col_values.append(len(str(header_names[i])))
            max_len_list.append(max(col_values))

        row_format_str = "".join(map(lambda len: f"{{:<{len + 4}}}", max_len_list))

        print(row_format_str.format(*header_names))
        for row in table_data:
            print(row_format_str.format(*row))

    endpoint = os.environ["DOCUMENTINTELLIGENCE_ENDPOINT"]
    key = os.environ["DOCUMENTINTELLIGENCE_API_KEY"]
    model_id = os.getenv("CUSTOM_BUILT_MODEL_ID", custom_model_id)

    document_intelligence_client = DocumentIntelligenceClient(endpoint=endpoint, credential=AzureKeyCredential(key))

    # Make sure your document's type is included in the list of document types the custom model can analyze
    with open(path_to_sample_documents, "rb") as f:
        poller = document_intelligence_client.begin_analyze_document(model_id=model_id, body=f)
    result: AnalyzeResult = poller.result()

    if result.documents:
        for idx, document in enumerate(result.documents):
            print(f"--------Analyzing document #{idx + 1}--------")
            print(f"Document has type {document.doc_type}")
            print(f"Document has document type confidence {document.confidence}")
            print(f"Document was analyzed with model with ID {result.model_id}")
            if document.fields:
                for name, field in document.fields.items():
                    field_value = field.get("valueString") if field.get("valueString") else field.content
                    print(
                        f"......found field of type '{field.type}' with value '{field_value}' and with confidence {field.confidence}"
                    )

        # Extract table cell values
        SYMBOL_OF_TABLE_TYPE = "array"
        SYMBOL_OF_OBJECT_TYPE = "object"
        KEY_OF_VALUE_OBJECT = "valueObject"
        KEY_OF_CELL_CONTENT = "content"

        for doc in result.documents:
            if not doc.fields is None:
                for field_name, field_value in doc.fields.items():
                    # Dynamic Table cell information store as array in document field.
                    if field_value.type == SYMBOL_OF_TABLE_TYPE and field_value.value_array:
                        col_names = []
                        sample_obj = field_value.value_array[0]
                        if KEY_OF_VALUE_OBJECT in sample_obj:
                            col_names = list(sample_obj[KEY_OF_VALUE_OBJECT].keys())
                        print("----Extracting Dynamic Table Cell Values----")
                        table_rows = []
                        for obj in field_value.value_array:
                            if KEY_OF_VALUE_OBJECT in obj:
                                value_obj = obj[KEY_OF_VALUE_OBJECT]
                                extract_value_by_col_name = lambda key: (
                                    value_obj[key].get(KEY_OF_CELL_CONTENT)
                                    if key in value_obj and KEY_OF_CELL_CONTENT in value_obj[key]
                                    else "None"
                                )
                                row_data = list(map(extract_value_by_col_name, col_names))
                                table_rows.append(row_data)
                        _print_table(col_names, table_rows)

                    elif (
                        field_value.type == SYMBOL_OF_OBJECT_TYPE
                        and KEY_OF_VALUE_OBJECT in field_value
                        and field_value[KEY_OF_VALUE_OBJECT] is not None
                    ):
                        rows_by_columns = list(field_value[KEY_OF_VALUE_OBJECT].values())
                        is_fixed_table = all(
                            (
                                rows_of_column["type"] == SYMBOL_OF_OBJECT_TYPE
                                and Counter(list(rows_by_columns[0][KEY_OF_VALUE_OBJECT].keys()))
                                == Counter(list(rows_of_column[KEY_OF_VALUE_OBJECT].keys()))
                            )
                            for rows_of_column in rows_by_columns
                        )

                        # Fixed Table cell information store as object in document field.
                        if is_fixed_table:
                            print("----Extracting Fixed Table Cell Values----")
                            col_names = list(field_value[KEY_OF_VALUE_OBJECT].keys())
                            row_dict: dict = {}
                            for rows_of_column in rows_by_columns:
                                rows = rows_of_column[KEY_OF_VALUE_OBJECT]
                                for row_key in list(rows.keys()):
                                    if row_key in row_dict:
                                        row_dict[row_key].append(rows[row_key].get(KEY_OF_CELL_CONTENT))
                                    else:
                                        row_dict[row_key] = [
                                            row_key,
                                            rows[row_key].get(KEY_OF_CELL_CONTENT),
                                        ]

                            col_names.insert(0, "")
                            _print_table(col_names, list(row_dict.values()))

    print("------------------------------------")
    # [END analyze_custom_documents]


if __name__ == "__main__":
    from azure.core.exceptions import HttpResponseError
    from dotenv import find_dotenv, load_dotenv

    try:
        load_dotenv(find_dotenv())
        model_id = None
        if os.getenv("DOCUMENTINTELLIGENCE_STORAGE_ADVANCED_CONTAINER_SAS_URL") and not os.getenv(
            "CUSTOM_BUILT_MODEL_ID"
        ):
            import uuid
            from azure.core.credentials import AzureKeyCredential
            from azure.ai.documentintelligence import DocumentIntelligenceAdministrationClient
            from azure.ai.documentintelligence.models import (
                DocumentBuildMode,
                BuildDocumentModelRequest,
                AzureBlobContentSource,
            )

            endpoint = os.getenv("DOCUMENTINTELLIGENCE_ENDPOINT")
            key = os.getenv("DOCUMENTINTELLIGENCE_API_KEY")

            if not endpoint or not key:
                raise ValueError("Please provide endpoint and API key to run the samples.")

            document_intelligence_admin_client = DocumentIntelligenceAdministrationClient(
                endpoint=endpoint, credential=AzureKeyCredential(key)
            )
            blob_container_sas_url = os.getenv("DOCUMENTINTELLIGENCE_STORAGE_ADVANCED_CONTAINER_SAS_URL")
            blob_prefix = os.getenv("DOCUMENTINTELLIGENCE_STORAGE_PREFIX")
            if blob_container_sas_url is not None:
                request = BuildDocumentModelRequest(
                    model_id=str(uuid.uuid4()),
                    build_mode=DocumentBuildMode.TEMPLATE,
                    azure_blob_source=AzureBlobContentSource(container_url=blob_container_sas_url, prefix=blob_prefix),
                )
                model = document_intelligence_admin_client.begin_build_document_model(request).result()
                model_id = model.model_id
        analyze_custom_documents(model_id)
    except HttpResponseError as error:
        # Examples of how to check an HttpResponseError
        # Check by error code:
        if error.error is not None:
            if error.error.code == "InvalidImage":
                print(f"Received an invalid image error: {error.error}")
            if error.error.code == "InvalidRequest":
                print(f"Received an invalid request error: {error.error}")
            # Raise the error again after printing it
            raise
        # If the inner error is None and then it is possible to check the message to get more information:
        if "Invalid request".casefold() in error.message.casefold():
            print(f"Uh-oh! Seems there was an invalid request: {error}")
        # Raise the error again
        raise



# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
from datetime import timedelta
import time
import pytest

from azure.communication.callautomation._models import ChannelAffinity, ServerCallLocator
from devtools_testutils import recorded_by_proxy

from callautomation_test_case import CallAutomationRecordedTestCase
from azure.communication.callautomation._shared.models import CommunicationUserIdentifier, identifier_from_raw_id


class TestCallAutomationClientAutomatedLiveTest(CallAutomationRecordedTestCase):

    @recorded_by_proxy
    def test_create_VOIP_call_and_answer_then_hangup(self):
        # try to establish the call
        caller = self.identity_client.create_user()
        target = self.identity_client.create_user()
        unique_id, call_connection, _ = self.establish_callconnection_voip(caller, target)

        # check returned events
        connected_event = self.check_for_event(
            "CallConnected", call_connection._call_connection_id, timedelta(seconds=15)
        )
        participant_updated_event = self.check_for_event(
            "ParticipantsUpdated", call_connection._call_connection_id, timedelta(seconds=15)
        )

        if connected_event is None:
            raise ValueError("Caller CallConnected event is None")
        if participant_updated_event is None:
            raise ValueError("Caller ParticipantsUpdated event is None")

        self.terminate_call(unique_id)
        return

    @recorded_by_proxy
    def test_add_participant_then_cancel_request(self):
        # try to establish the call
        caller = self.identity_client.create_user()
        target = self.identity_client.create_user()
        participant_to_add = identifier_from_raw_id(self.identity_client.create_user().raw_id)
        unique_id, call_connection, _ = self.establish_callconnection_voip(caller, target)

        # check returned events
        connected_event = self.check_for_event(
            "CallConnected", call_connection._call_connection_id, timedelta(seconds=15)
        )
        participant_updated_event = self.check_for_event(
            "ParticipantsUpdated", call_connection._call_connection_id, timedelta(seconds=15)
        )

        if connected_event is None:
            raise ValueError("Caller CallConnected event is None")
        if participant_updated_event is None:
            raise ValueError("Caller ParticipantsUpdated event is None")

        add_participant_result = call_connection.add_participant(participant_to_add)

        # ensure invitation is sent
        time.sleep(3)

        call_connection.cancel_add_participant_operation(add_participant_result.invitation_id)

        cancel_add_participant_succeeded_event = self.check_for_event(
            "CancelAddParticipantSucceeded", call_connection._call_connection_id, timedelta(seconds=15)
        )

        if cancel_add_participant_succeeded_event is None:
            raise ValueError("Caller CancelAddParticipantSucceeded event is None")

        self.terminate_call(unique_id)
        return
    
    @pytest.mark.skip(reason="""Playback fails for same event type triggered and test recording code
                       takes the event type has the dictionary it fails to recording call connected event for the connect api""")
    @recorded_by_proxy
    def test_create_VOIP_call_and_connect_call_then_hangup(self):
        # try to establish the call
        caller = self.identity_client.create_user()
        target = self.identity_client.create_user()
        unique_id, call_connection, _, call_automation_client, callback_url = self.establish_callconnection_voip_connect_call(caller, target)

        # check returned events
        connected_event = self.check_for_event('CallConnected', call_connection._call_connection_id, timedelta(seconds=15))
        participant_updated_event = self.check_for_event('ParticipantsUpdated', call_connection._call_connection_id, timedelta(seconds=15))

        if connected_event is None:
            raise ValueError("Caller CallConnected event is None")
        if participant_updated_event is None:
            raise ValueError("Caller ParticipantsUpdated event is None")

        call_connection_properties = call_connection.get_call_properties()
        server_call_id = call_connection_properties.server_call_id

        # connect call request.
        connect_call_connection = call_automation_client.connect_call(
            server_call_id=server_call_id,
            callback_url=callback_url,
            )

        # check returned call connected events
        connect_call_connected_event = self.check_for_event('CallConnected', connect_call_connection.call_connection_id, timedelta(seconds=20))
        if connect_call_connected_event is None:
            raise ValueError("Caller CallConnected event is None")

        self.terminate_call(unique_id)
        return
    
    @recorded_by_proxy
    def test_create_VOIP_call_and_answer_custom_context(self):
        # try to establish the call
        caller = self.identity_client.create_user()
        target = self.identity_client.create_user()
        unique_id, call_connection, _ = self.establish_callconnection_voip_answercall_withcustomcontext(caller, target)

        # check returned events
        connected_event = self.check_for_event(
            "CallConnected", call_connection._call_connection_id, timedelta(seconds=15)
        )
        participant_updated_event = self.check_for_event(
            "ParticipantsUpdated", call_connection._call_connection_id, timedelta(seconds=15)
        )

        if connected_event is None:
            raise ValueError("Caller CallConnected event is None")
        if participant_updated_event is None:
            raise ValueError("Caller ParticipantsUpdated event is None")

        self.terminate_call(unique_id)
        return

    @recorded_by_proxy
    def test_start_recording_with_call_connection_id(self):
     # try to establish the call
     caller = self.identity_client.create_user()
     target = self.identity_client.create_user()
     unique_id, call_connection, _, call_automation_client, callback_url = self.establish_callconnection_voip_connect_call(caller, target)

     # check returned events
     connected_event = self.check_for_event('CallConnected', call_connection._call_connection_id, timedelta(seconds=15))
     participant_updated_event = self.check_for_event('ParticipantsUpdated', call_connection._call_connection_id, timedelta(seconds=15))

     if connected_event is None:
         raise ValueError("Caller CallConnected event is None")
     if participant_updated_event is None:
         raise ValueError("Caller ParticipantsUpdated event is None")

     call_connection_properties = call_connection.get_call_properties()
     call_connection_id = call_connection_properties.call_connection_id
     target_participant = CommunicationUserIdentifier("testId")
     channel_affinity = ChannelAffinity(target_participant=target_participant, channel=0)
     
     # start recording request with call connection id.
     start_recording = call_automation_client.start_recording(call_connection_id=call_connection_id, recording_state_callback_url=callback_url, channel_affinity=[channel_affinity]
         )
     time.sleep(5)

     # check for RecordingStateChanged event
     recording_state_changed_event = self.check_for_event('RecordingStateChanged', call_connection_id, timedelta(seconds=30))
     if recording_state_changed_event is None:
         raise ValueError("RecordingStateChanged event is None")
     
     # stop recording request.
     call_automation_client.stop_recording(recording_id=start_recording.recording_id)
     time.sleep(3)
     
     self.terminate_call(unique_id)
     return

    @recorded_by_proxy
    def test_start_recording_with_server_call_id(self):
     # try to establish the call
     caller = self.identity_client.create_user()
     target = self.identity_client.create_user()
     unique_id, call_connection, _, call_automation_client, callback_url = self.establish_callconnection_voip_connect_call(caller, target)

     # check returned events
     connected_event = self.check_for_event('CallConnected', call_connection._call_connection_id, timedelta(seconds=15))
     participant_updated_event = self.check_for_event('ParticipantsUpdated', call_connection._call_connection_id, timedelta(seconds=15))

     if connected_event is None:
         raise ValueError("Caller CallConnected event is None")
     if participant_updated_event is None:
         raise ValueError("Caller ParticipantsUpdated event is None")

     call_connection_properties = call_connection.get_call_properties()
     call_connection_id = call_connection_properties.call_connection_id
     server_call_id = call_connection_properties.server_call_id
     target_participant = CommunicationUserIdentifier("testId")
     channel_affinity = ChannelAffinity(target_participant=target_participant, channel=0)

     # start recording request with call connection id.
     start_recording = call_automation_client.start_recording(server_call_id = server_call_id, recording_state_callback_url=callback_url, channel_affinity=[channel_affinity]
         )
     time.sleep(5)

     # check for RecordingStateChanged event
     recording_state_changed_event = self.check_for_event('RecordingStateChanged', call_connection_id, timedelta(seconds=30))
     if recording_state_changed_event is None:
         raise ValueError("RecordingStateChanged event is None")
     
     # stop recording request.
     call_automation_client.stop_recording(recording_id=start_recording.recording_id)
     time.sleep(3)
     
     self.terminate_call(unique_id)
     return



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
from collections.abc import MutableMapping
from typing import Any, Callable, Dict, List, Optional, TypeVar

from azure.core import AsyncPipelineClient
from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.rest import AsyncHttpResponse, HttpRequest
from azure.core.tracing.decorator_async import distributed_trace_async
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat

from ... import models as _models
from ..._utils.utils import ClientMixinABC
from ...operations._cognitive_services_management_client_operations import (
    build_calculate_model_capacity_request,
    build_check_domain_availability_request,
    build_check_sku_availability_request,
)
from .._configuration import CognitiveServicesManagementClientConfiguration

T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]]


class CognitiveServicesManagementClientOperationsMixin(  # pylint: disable=name-too-long
    ClientMixinABC[AsyncPipelineClient, CognitiveServicesManagementClientConfiguration]
):

    @distributed_trace_async
    async def check_sku_availability(
        self, location: str, skus: List[str], kind: str, type: str, **kwargs: Any
    ) -> _models.SkuAvailabilityListResult:
        """Check available SKUs.

        :param location: Resource location. Required.
        :type location: str
        :param skus: The SKU of the resource. Required.
        :type skus: list[str]
        :param kind: The kind (type) of cognitive service account. Required.
        :type kind: str
        :param type: The Type of the resource. Required.
        :type type: str
        :return: SkuAvailabilityListResult or the result of cls(response)
        :rtype: ~azure.mgmt.cognitiveservices.models.SkuAvailabilityListResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map: MutableMapping = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        content_type: str = kwargs.pop("content_type", _headers.pop("Content-Type", "application/json"))
        cls: ClsType[_models.SkuAvailabilityListResult] = kwargs.pop("cls", None)

        _parameters = _models.CheckSkuAvailabilityParameter(kind=kind, skus=skus, type=type)
        _json = self._serialize.body(_parameters, "CheckSkuAvailabilityParameter")

        _request = build_check_sku_availability_request(
            location=location,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            headers=_headers,
            params=_params,
        )
        _request.url = self._client.format_url(_request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            _request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("SkuAvailabilityListResult", pipeline_response.http_response)

        if cls:
            return cls(pipeline_response, deserialized, {})  # type: ignore

        return deserialized  # type: ignore

    @distributed_trace_async
    async def check_domain_availability(
        self, subdomain_name: str, type: str, kind: Optional[str] = None, **kwargs: Any
    ) -> _models.DomainAvailability:
        """Check whether a domain is available.

        :param subdomain_name: The subdomain name to use. Required.
        :type subdomain_name: str
        :param type: The Type of the resource. Required.
        :type type: str
        :param kind: The Kind of the resource. Default value is None.
        :type kind: str
        :return: DomainAvailability or the result of cls(response)
        :rtype: ~azure.mgmt.cognitiveservices.models.DomainAvailability
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map: MutableMapping = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        content_type: str = kwargs.pop("content_type", _headers.pop("Content-Type", "application/json"))
        cls: ClsType[_models.DomainAvailability] = kwargs.pop("cls", None)

        _parameters = _models.CheckDomainAvailabilityParameter(kind=kind, subdomain_name=subdomain_name, type=type)
        _json = self._serialize.body(_parameters, "CheckDomainAvailabilityParameter")

        _request = build_check_domain_availability_request(
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            headers=_headers,
            params=_params,
        )
        _request.url = self._client.format_url(_request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            _request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("DomainAvailability", pipeline_response.http_response)

        if cls:
            return cls(pipeline_response, deserialized, {})  # type: ignore

        return deserialized  # type: ignore

    @distributed_trace_async
    async def calculate_model_capacity(
        self,
        model: Optional[_models.DeploymentModel] = None,
        sku_name: Optional[str] = None,
        workloads: Optional[List[_models.ModelCapacityCalculatorWorkload]] = None,
        **kwargs: Any
    ) -> _models.CalculateModelCapacityResult:
        """Model capacity calculator.

        :param model: Properties of Cognitive Services account deployment model. Default value is None.
        :type model: ~azure.mgmt.cognitiveservices.models.DeploymentModel
        :param sku_name: The name of SKU. Default value is None.
        :type sku_name: str
        :param workloads: List of Model Capacity Calculator Workload. Default value is None.
        :type workloads: list[~azure.mgmt.cognitiveservices.models.ModelCapacityCalculatorWorkload]
        :return: CalculateModelCapacityResult or the result of cls(response)
        :rtype: ~azure.mgmt.cognitiveservices.models.CalculateModelCapacityResult
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map: MutableMapping = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version: str = kwargs.pop("api_version", _params.pop("api-version", self._config.api_version))
        content_type: str = kwargs.pop("content_type", _headers.pop("Content-Type", "application/json"))
        cls: ClsType[_models.CalculateModelCapacityResult] = kwargs.pop("cls", None)

        _parameters = _models.CalculateModelCapacityParameter(model=model, sku_name=sku_name, workloads=workloads)
        _json = self._serialize.body(_parameters, "CalculateModelCapacityParameter")

        _request = build_calculate_model_capacity_request(
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            headers=_headers,
            params=_params,
        )
        _request.url = self._client.format_url(_request.url)

        _stream = False
        pipeline_response: PipelineResponse = await self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            _request, stream=_stream, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            error = self._deserialize.failsafe_deserialize(_models.ErrorResponse, pipeline_response)
            raise HttpResponseError(response=response, model=error, error_format=ARMErrorFormat)

        deserialized = self._deserialize("CalculateModelCapacityResult", pipeline_response.http_response)

        if cls:
            return cls(pipeline_response, deserialized, {})  # type: ignore

        return deserialized  # type: ignore



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.containerservicefleet import ContainerServiceFleetMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-containerservicefleet
# USAGE
    python update_runs_delete_maximum_set_gen.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = ContainerServiceFleetMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="00000000-0000-0000-0000-000000000000",
    )

    client.update_runs.begin_delete(
        resource_group_name="rgfleets",
        fleet_name="fleet1",
        update_run_name="fleet1",
    ).result()


# x-ms-original-file: specification/containerservice/resource-manager/Microsoft.ContainerService/fleet/stable/2025-03-01/examples/UpdateRuns_Delete_MaximumSet_Gen.json
if __name__ == "__main__":
    main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: download_media.py

DESCRIPTION:
    This sample demonstrates receiving media from a Whatsapp message from business phone number. The NotificationMessageClient is 
    authenticated using a connection string.
USAGE:
    python download_media.py

    Set the environment variable with your own value before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS resource
"""

import os
import sys
from io import RawIOBase

sys.path.append("..")


class DownloadMediaSample(object):

    connection_string = os.getenv("COMMUNICATION_SAMPLES_CONNECTION_STRING")

    def download_media(self):

        from azure.communication.messages import NotificationMessagesClient

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)
        input_media_id: str = "de7558b5-e169-4d47-9ba4-37a95c28f390"

        # calling send() with whatsapp message details
        media_stream = messaging_client.download_media(input_media_id)
        length: int = 0
        for byte in media_stream:
            length = length + 1
        print("WhatsApp Media stream downloaded.It's length is {}".format(length))


if __name__ == "__main__":
    sample = DownloadMediaSample()
    sample.download_media()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from typing import Any, IO, Union

from azure.identity import DefaultAzureCredential

from azure.mgmt.dataprotection import DataProtectionMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-dataprotection
# USAGE
    python put_resource_guard_proxy.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DataProtectionMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="5e13b949-1218-4d18-8b99-7e12155ec4f7",
    )

    response = client.dpp_resource_guard_proxy.create_or_update(
        resource_group_name="SampleResourceGroup",
        vault_name="sampleVault",
        resource_guard_proxy_name="swaggerExample",
        parameters={
            "properties": {
                "resourceGuardResourceId": "/subscriptions/f9e67185-f313-4e79-aa71-6458d429369d/resourceGroups/ResourceGuardSecurityAdminRG/providers/Microsoft.DataProtection/resourceGuards/ResourceGuardTestResource"
            }
        },
    )
    print(response)


# x-ms-original-file: specification/dataprotection/resource-manager/Microsoft.DataProtection/stable/2024-04-01/examples/ResourceGuardProxyCRUD/PutResourceGuardProxy.json
if __name__ == "__main__":
    main()



# The MIT License (MIT)
# Copyright (c) 2024 Microsoft Corporation

from typing import Any, Dict, Iterable, Mapping, Optional, List
from azure.core.utils import CaseInsensitiveDict


class CosmosDict(Dict[str, Any]):
    def __init__(self, original_dict: Optional[Mapping[str, Any]], /, *, response_headers: CaseInsensitiveDict) -> None:
        if original_dict is None:
            original_dict = {}
        super().__init__(original_dict)
        self._response_headers = response_headers

    def get_response_headers(self) -> CaseInsensitiveDict:
        """Returns a copy of the response headers associated to this response

        :return: Dict of response headers
        :rtype: ~azure.core.CaseInsensitiveDict
        """
        return self._response_headers.copy()


class CosmosList(List[Dict[str, Any]]):
    def __init__(self, original_list: Optional[Iterable[Dict[str, Any]]], /, *,
                 response_headers: CaseInsensitiveDict) -> None:
        if original_list is None:
            original_list = []
        super().__init__(original_list)
        self._response_headers = response_headers

    def get_response_headers(self) -> CaseInsensitiveDict:
        """Returns a copy of the response headers associated to this response

        :return: Dict of response headers
        :rtype: ~azure.core.CaseInsensitiveDict
        """
        return self._response_headers.copy()
